@@ -1,7 +1,7 @@
 //! Paperclip is a OpenAPI code generator for efficient type-safe
 //! compile-time checked HTTP APIs in Rust.
 //!
-//! See the [website](https://paperclip.waffles.space) for detailed
+//! See the [website](https://paperclip-rs.github.io/paperclip) for detailed
 //! documentation and examples.
 
 #[cfg_attr(feature = "codegen", macro_use)]
@@ -28,4 +28,7 @@ pub mod actix {
     pub use paperclip_core::v2::{
         AcceptedJson, CreatedJson, NoContent, OperationModifier, ResponderWrapper, ResponseWrapper,
     };
+
+    #[cfg(feature = "actix4")]
+    pub use paperclip_core::v2::HttpResponseWrapper;
 }
